pub enum TraceEvent {
NewSpan {
id: u64,
name: &'static str,
target: &'static str,
level: Level,
fields: SmallVec<[(&'static str, FieldValue); 4]>,
timestamp: SystemTime,
parent_id: Option<u64>,
thread_name: &'static str,
file: Option<&'static str>,
line: Option<u32>,
},
SpanEnter {
id: u64,
timestamp: SystemTime,
thread_name: &'static str,
},
SpanExit {
id: u64,
timestamp: SystemTime,
thread_name: &'static str,
},
SpanClose {
id: u64,
timestamp: SystemTime,
},
Event {
name: &'static str,
target: &'static str,
level: Level,
fields: SmallVec<[(&'static str, FieldValue); 4]>,
timestamp: SystemTime,
parent_span: Option<u64>,
thread_id: &'static str,
thread_name: &'static str,
module_path: Option<&'static str>,
file: Option<&'static str>,
line: Option<u32>,
},
}Expand description
Unified representation of a trace event captured from the tracing layer. This is captured once on the application thread, then sent to the background worker for fan-out to multiple exporters.
Variants
NewSpan
A new span was created (on_new_span)
SpanEnter
A span was entered (on_enter)
SpanExit
A span was exited (on_exit)
SpanClose
A span was closed (dropped)
Event
A tracing event occurred (e.g., tracing::info!())